@@ -104,37 +104,16 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
         page_types = {}
         master_table = {}
 
-        def get_int(raw):
-            return int.from_bytes(raw, byteorder='big', signed=True)
-
-        def get_none(_):
-            return None
-
-        def identity(raw):
-            return raw
-
-        integer_serial_types = {
-            1: (1, get_int),
-            2: (2, get_int),
-            3: (3, get_int),
-            4: (4, get_int),
-            5: (6, get_int),
-            6: (8, get_int),
-            8: (0, lambda _: 0),
-            9: (0, lambda _: 1),
-        }
-
         def process_table_page(table_name, page_bytes, page_reader):
 
-            def get_length_parser(serial_type):
-                return \
-                    (0, get_none) if serial_type == 0 else \
-                    integer_serial_types[serial_type] if serial_type < 12 else \
-                    (int((serial_type - 12)/2), identity) if serial_type % 2 == 0 else \
-                    (int((serial_type - 13)/2), identity) if serial_type % 2 == 1 else \
-                    None
-
             def yield_leaf_table_cells(page_bytes, pointers):
+
+                def serial_types(header_remaining, cell_varint_reader):
+                    while header_remaining:
+                        h, v_size = cell_varint_reader()
+                        yield h
+                        header_remaining -= v_size
+
                 for pointer in pointers:
                     cell_num_reader, cell_varint_reader = get_chunk_readers(page_bytes, pointer)
 
@@ -144,17 +123,24 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
                     header_remaining, header_varint_size = cell_varint_reader()
                     header_remaining -= header_varint_size
 
-                    serial_types = []
-                    while header_remaining:
-                        h, v_size = cell_varint_reader()
-                        serial_types.append(h)
-                        header_remaining -= v_size
-
-                    yield [
+                    yield tuple(
                         parser(cell_num_reader(length))
-                        for serial_type in serial_types
-                        for (length, parser) in [get_length_parser(serial_type)]
-                    ]
+                        for serial_type in tuple(serial_types(header_remaining, cell_varint_reader))
+                        for (length, parser) in (
+                            (0, lambda _: None) if serial_type == 0 else \
+                            (1, lambda raw: int.from_bytes(raw, byteorder='big', signed=True)) if serial_type == 1 else \
+                            (2, lambda raw: int.from_bytes(raw, byteorder='big', signed=True)) if serial_type == 2 else \
+                            (3, lambda raw: int.from_bytes(raw, byteorder='big', signed=True)) if serial_type == 3 else \
+                            (4, lambda raw: int.from_bytes(raw, byteorder='big', signed=True)) if serial_type == 4 else \
+                            (6, lambda raw: int.from_bytes(raw, byteorder='big', signed=True)) if serial_type == 5 else \
+                            (8, lambda raw: int.from_bytes(raw, byteorder='big', signed=True)) if serial_type == 6 else \
+                            (0, lambda _: 0) if serial_type == 8 else \
+                            (0, lambda _: 1) if serial_type == 9 else \
+                            (int((serial_type - 12)/2), lambda raw: raw) if serial_type % 2 == 0 else \
+                            (int((serial_type - 13)/2), lambda raw: raw) if serial_type % 2 == 1 else \
+                            (None, None),
+                        )
+                    )
 
             def yield_interior_table_cells(page_bytes, pointers):
                 for pointer in pointers:
@@ -169,12 +155,12 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
                     cur.execute("PRAGMA table_info('" + table_name + "');")
                     rows = cur.fetchall()
                     cols = [d[0] for d in cur.description]
-                    return [{col: row[i] for i, col in enumerate(cols)} for row in rows]
+                    return tuple({col: row[i] for i, col in enumerate(cols)} for row in rows)
 
                 with connect(':memory:') as con:
                     cur = con.cursor()
 
-                    return [
+                    return tuple(
                         {
                             'name': cell[1].decode(),
                             'info': schema(cur, cell[1].decode(), cell[4].decode()),
@@ -182,7 +168,7 @@ def stream_sqlite(sqlite_chunks, chunk_size=65536):
                         }
                         for cell in master_cells
                         if cell[0] == b'table'
-                    ]
+                    )
 
             def process_if_buffered_or_remember(table_name, page_num):
                 try:
